@@ -9,7 +9,7 @@
 //! # Command-line Interface
 //!
 //! ```text
-//! rezip 0.1.2
+//! rezip 0.1.3
 //! Rouven Spreckels <rs@qu1x.dev>
 //! Merges ZIP/NPZ archives recompressed or aligned and stacks NPY arrays
 //!
@@ -24,7 +24,7 @@
 //! default values.
 //!
 //! USAGE:
-//!     rezip [OPTIONS] [--] [glob]...
+//!     rezip [OPTIONS] [glob]...
 //!
 //! ARGS:
 //!     <glob>...
@@ -46,7 +46,7 @@
 //!     -f, --force
 //!             Writes existing output ZIP archive
 //!
-//!     -m, --merge <[glob=]name>...
+//!     -m, --merge <[glob=]name>
 //!             Merges files as if they were in ZIP archives.
 //!
 //!             Merges files as if they were in different ZIP archives and renames
@@ -56,7 +56,7 @@
 //!             Note: File permissions and its last modification time are not yet
 //!             supported.
 //!
-//!     -r, --recompress <[glob=]method>...
+//!     -r, --recompress <[glob=]method>
 //!             Writes files recompressed.
 //!
 //!             Supported methods are stored (uncompressed), deflated (most common),
@@ -64,22 +64,26 @@
 //!             (modern) with 3 as default level. With no methods, files are
 //!             recompressed using their original methods but with default levels.
 //!
-//!             Note: Compression levels and method zstd are not yet supported.
+//!             Note: Compression levels are not yet supported.
+//!
 //!             [default: stored]
 //!
-//!     -a, --align <[glob=]bytes>...
+//!     -a, --align <[glob=]bytes>
 //!             Aligns uncompressed files.
 //!
 //!             Aligns uncompressed files in ZIP archives by padding local file
 //!             headers to enable memory-mapping, SIMD instruction extensions like
-//!             AVX-512, and dynamic loading of shared objects. [default: 64
-//!             *.so=4096]
+//!             AVX-512, and dynamic loading of shared objects.
 //!
-//!     -s, --stack <[glob=]axis>...
+//!             [default: 64 *.so=4096]
+//!
+//!     -s, --stack <[glob=]axis>
 //!             Stacks arrays along axis.
 //!
 //!             One stacked array at a time must fit twice into memory before it is
-//!             written to the output ZIP archive. [default: 0]
+//!             written to the output ZIP archive.
+//!
+//!             [default: 0]
 //!
 //!     -v, --verbose
 //!             Prints status information.
@@ -87,11 +91,10 @@
 //!             The more occurrences, the more verbose, with three at most.
 //!
 //!     -h, --help
-//!             Prints help information
+//!             Print help information
 //!
 //!     -V, --version
-//!             Prints version information
-//!
+//!             Print version information
 //! ```
 
 #![forbid(unsafe_code)]
@@ -128,7 +131,7 @@ use zip::{read::ZipFile, write::FileOptions, CompressionMethod, DateTime, ZipArc
 	version = crate_version!(),
 	author = crate_authors!(),
 	global_setting = AppSettings::DeriveDisplayOrder,
-	global_setting = AppSettings::ArgRequiredElseHelp,
+	arg_required_else_help = true,
 )]
 struct Rezip {
 	/// Merges or checks input ZIP archives.
@@ -161,7 +164,7 @@ struct Rezip {
 	/// ratio) with 9 as default level, and zstd[:1-21] (modern) with 3 as default level. With no
 	/// methods, files are recompressed using their original methods but with default levels.
 	///
-	/// Note: Compression levels and method zstd are not yet supported.
+	/// Note: Compression levels are not yet supported.
 	#[clap(short, long, value_name = "[glob=]method", default_values = &["stored"])]
 	recompress: Vec<String>,
 	/// Aligns uncompressed files.
@@ -425,18 +428,17 @@ fn main() -> Result<()> {
 					})
 				})
 				.map(|level| (CompressionMethod::Bzip2, level)),
-			// TODO
-			//(Some("zstd"), level) => level
-			//	.map_or(Ok(Some(3)), |level| {
-			//		level.parse::<i32>().map_err(From::from).and_then(|level| {
-			//			if (1..=21).contains(&level) {
-			//				Ok(Some(level))
-			//			} else {
-			//				Err(eyre!("Invalid level in {:?}", method))
-			//			}
-			//		})
-			//	})
-			//	.map(|level| (CompressionMethod::Zstd, level)),
+			(Some("zstd"), level) => level
+				.map_or(Ok(Some(3)), |level| {
+					level.parse::<i32>().map_err(From::from).and_then(|level| {
+						if (1..=21).contains(&level) {
+							Ok(Some(level))
+						} else {
+							Err(eyre!("Invalid level in {:?}", method))
+						}
+					})
+				})
+				.map(|level| (CompressionMethod::Zstd, level)),
 			(Some(_), _) => Err(eyre!("Unsupported method {:?}", method)),
 			_ => Err(eyre!("Invalid method {:?}", method)),
 		}
